==> apiverve_timezonelookup-1.0.11.tar.gz: apiverve_timezonelookup-1.0.11/README.md <==
Timezone Lookup API
============

Timezone Lookup is a simple tool for looking up timezone data. It returns the timezone name, offset, and more.

![Build Status](https://img.shields.io/badge/build-passing-green)
![Code Climate](https://img.shields.io/badge/maintainability-B-purple)
![Prod Ready](https://img.shields.io/badge/production-ready-blue)

This is a Python API Wrapper for the [Timezone Lookup API](https://apiverve.com/marketplace/api/timezonelookup)

---

## Installation
	pip install apiverve-timezonelookup

---

## Configuration

Before using the timezonelookup API client, you have to setup your account and obtain your API Key.  
You can get it by signing up at [https://apiverve.com](https://apiverve.com)

---

## Usage

The Timezone Lookup API documentation is found here: [https://docs.apiverve.com/api/timezonelookup](https://docs.apiverve.com/api/timezonelookup).  
You can find parameters, example responses, and status codes documented here.

### Setup

```
# Import the client module
from apiverve_timezonelookup.apiClient import TimezonelookupAPIClient

# Initialize the client with your APIVerve API key
api = TimezonelookupAPIClient("[YOUR_API_KEY]")
```

---


### Perform Request
Using the API client, you can perform requests to the API.

###### Define Query

```
query = { "timezone": "America/New_York" }
```

###### Simple Request

```
# Make a request to the API
result = api.execute(query)

# Print the result
print(result)
```

###### Example Response

```
{
  "status": "ok",
  "error": null,
  "data": {
    "timezone": "America/New_York",
    "timezone_offset": -240,
    "date": "2024-05-15",
    "time": "17:53",
    "time24": "17:53:17",
    "time12": "05:53:17 PM",
    "day": "Wednesday",
    "month": "May",
    "year": "2024",
    "unix": "1715809997",
    "dst": true,
    "dst_start": "2024-05-15 17:53:17",
    "dst_end": "2024-05-15 17:53:17",
    "dst_name": "EDT"
  }
}
```

---

## Customer Support

Need any assistance? [Get in touch with Customer Support](https://apiverve.com/contact).

---

## Updates
Stay up to date by following [@apiverveHQ](https://twitter.com/apiverveHQ) on Twitter.

---

## Legal

All usage of the APIVerve website, API, and services is subject to the [APIVerve Terms of Service](https://apiverve.com/terms) and all legal documents and agreements.

---

## License
Licensed under the The MIT License (MIT)

Copyright (&copy;) 2024 APIVerve, and Evlar LLC

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

==> apiverve_timezonelookup-1.1.4.tar.gz: apiverve_timezonelookup-1.1.4/README.md <==
Timezone Lookup API
============

Timezone Lookup is a simple tool for looking up timezone data. It returns the timezone name, offset, and more.

![Build Status](https://img.shields.io/badge/build-passing-green)
![Code Climate](https://img.shields.io/badge/maintainability-B-purple)
![Prod Ready](https://img.shields.io/badge/production-ready-blue)

This is a Python API Wrapper for the [Timezone Lookup API](https://apiverve.com/marketplace/api/timezonelookup)

---

## Installation
	pip install apiverve-timezonelookup

---

## Configuration

Before using the timezonelookup API client, you have to setup your account and obtain your API Key.  
You can get it by signing up at [https://apiverve.com](https://apiverve.com)

---

## Usage

The Timezone Lookup API documentation is found here: [https://docs.apiverve.com/api/timezonelookup](https://docs.apiverve.com/api/timezonelookup).  
You can find parameters, example responses, and status codes documented here.

### Setup

```
# Import the client module
from apiverve_timezonelookup.apiClient import TimezonelookupAPIClient

# Initialize the client with your APIVerve API key
api = TimezonelookupAPIClient("[YOUR_API_KEY]")
```

---


### Perform Request
Using the API client, you can perform requests to the API.

###### Define Query

```
query = { "city": "Harare" }
```

###### Simple Request

```
# Make a request to the API
result = api.execute(query)

# Print the result
print(result)
```

###### Example Response

```
{
  "status": "ok",
  "error": null,
  "data": {
    "timezone": "Africa/Harare",
    "timezone_offset": 120,
    "date": "2024-08-14",
    "time": "08:18",
    "time24": "08:18:10",
    "time12": "08:18:10 AM",
    "day": "Wednesday",
    "month": "August",
    "year": "2024",
    "unix": "1723616290",
    "dst": false,
    "dst_start": "2024-08-14 08:18:10",
    "dst_end": "2024-08-14 08:18:10",
    "dst_name": "CAT"
  },
  "code": 200
}
```

---

## Customer Support

Need any assistance? [Get in touch with Customer Support](https://apiverve.com/contact).

---

## Updates
Stay up to date by following [@apiverveHQ](https://twitter.com/apiverveHQ) on Twitter.

---

## Legal

All usage of the APIVerve website, API, and services is subject to the [APIVerve Terms of Service](https://apiverve.com/terms) and all legal documents and agreements.

---

## License
Licensed under the The MIT License (MIT)

Copyright (&copy;) 2024 APIVerve, and Evlar LLC

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
